@@ -9,6 +9,8 @@ ex_query <- function(n = 5) {
 
 test_that("download escreve arquivos recebendo uma query ou nome de tabela", {
 
+  testthat::skip_on_cran()
+
   path <- file.path(tempdir(), "arquivo.csv")
 
     download(
@@ -24,7 +26,6 @@ test_that("download escreve arquivos recebendo uma query ou nome de tabela", {
   download(
     table = "br_ibge_populacao.municipio",
     path = path,
-    page_size = 123432,
     .na = "999999999999")
 
   path %>%
@@ -35,6 +36,8 @@ test_that("download escreve arquivos recebendo uma query ou nome de tabela", {
 
 test_that("download permite escolher o conteúdo de NAs", {
 
+  testthat::skip_on_cran()
+
   path3 <- file.path(tempdir(), "arquivo3.csv")
 
   download(
@@ -59,12 +62,13 @@ test_that("download permite escolher o conteúdo de NAs", {
 
 test_that("download permite escolher tamanho de página", {
 
+  testthat::skip_on_cran()
+
   path4 <- file.path(tempdir(), "arquivo4.csv")
 
   download(
     ex_query(),
-    path = path4,
-    page_size = 123432)
+    path = path4)
 
   path4 %>%
     fs::is_file() %>%
@@ -74,6 +78,8 @@ test_that("download permite escolher tamanho de página", {
 
 test_that("download valida nomes de arquivos sem extensão", {
 
+  testthat::skip_on_cran()
+
   expect_error(
     download(
       ex_query(),
@@ -84,6 +90,8 @@ test_that("download valida nomes de arquivos sem extensão", {
 
 test_that("read_sql e read_table retornam um tibble com as propriedades esperadas", {
 
+  testthat::skip_on_cran()
+
   testthat::expect_s3_class(read_sql(ex_query(1)), "tbl_df")
 
   read_sql(ex_query(5)) %>%
@@ -100,6 +108,8 @@ test_that("read_sql e read_table retornam um tibble com as propriedades esperada
 
 test_that("read_sql e read_table falham com input inapropriado", {
 
+  testthat::skip_on_cran()
+
   expect_error(read_sql(query = 123))
   expect_error(read_sql(query = TRUE))
   expect_error(read_sql(query = "sodfungosd"))
